==> openshift-model-6.9.0-sources.jar: io/fabric8/openshift/api/model/GitHubWebHookCauseFluent.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class GitHubWebHookCauseFluent<A extends GitHubWebHookCauseFluent<A>> extends BaseFluent<A>{
  public GitHubWebHookCauseFluent() {
  }
  
  public GitHubWebHookCauseFluent(GitHubWebHookCause instance) {
    this.copyInstance(instance);
  }
  private SourceRevisionBuilder revision;
  private String secret;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(GitHubWebHookCause instance) {
    instance = (instance != null ? instance : new GitHubWebHookCause());
  
    if (instance != null) {
        this.withRevision(instance.getRevision());
        this.withSecret(instance.getSecret());
        this.withRevision(instance.getRevision());
        this.withSecret(instance.getSecret());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public SourceRevision buildRevision() {
    return this.revision!=null ?this.revision.build():null;
  }
  
  public A withRevision(SourceRevision revision) {
    _visitables.get("revision").remove(this.revision);
    if (revision!=null){ this.revision= new SourceRevisionBuilder(revision); _visitables.get("revision").add(this.revision);} else { this.revision = null; _visitables.get("revision").remove(this.revision); } return (A) this;
  }
  
  public boolean hasRevision() {
    return this.revision != null;
  }
  
  public RevisionNested<A> withNewRevision() {
    return new RevisionNested(null);
  }
  
  public RevisionNested<A> withNewRevisionLike(SourceRevision item) {
    return new RevisionNested(item);
  }
  
  public RevisionNested<A> editRevision() {
    return withNewRevisionLike(java.util.Optional.ofNullable(buildRevision()).orElse(null));
  }
  
  public RevisionNested<A> editOrNewRevision() {
    return withNewRevisionLike(java.util.Optional.ofNullable(buildRevision()).orElse(new SourceRevisionBuilder().build()));
  }
  
  public RevisionNested<A> editOrNewRevisionLike(SourceRevision item) {
    return withNewRevisionLike(java.util.Optional.ofNullable(buildRevision()).orElse(item));
  }
  
  public String getSecret() {
    return this.secret;
  }
  
  public A withSecret(String secret) {
    this.secret=secret; return (A) this;
  }
  
  public boolean hasSecret() {
    return this.secret != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    GitHubWebHookCauseFluent that = (GitHubWebHookCauseFluent) o;
    if (!java.util.Objects.equals(revision, that.revision)) return false;
  
    if (!java.util.Objects.equals(secret, that.secret)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(revision,  secret,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (revision != null) { sb.append("revision:"); sb.append(revision + ","); }
    if (secret != null) { sb.append("secret:"); sb.append(secret + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class RevisionNested<N> extends SourceRevisionFluent<RevisionNested<N>> implements Nested<N>{
    RevisionNested(SourceRevision item) {
      this.builder = new SourceRevisionBuilder(this, item);
    }
    SourceRevisionBuilder builder;
    
    public N and() {
      return (N) GitHubWebHookCauseFluent.this.withRevision(builder.build());
    }
    
    public N endRevision() {
      return and();
    }
    
  
  }

}

==> openshift-model-6.9.1-sources.jar: io/fabric8/openshift/api/model/GitHubWebHookCauseFluent.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class GitHubWebHookCauseFluent<A extends GitHubWebHookCauseFluent<A>> extends BaseFluent<A>{
  public GitHubWebHookCauseFluent() {
  }
  
  public GitHubWebHookCauseFluent(GitHubWebHookCause instance) {
    this.copyInstance(instance);
  }
  private SourceRevisionBuilder revision;
  private String secret;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(GitHubWebHookCause instance) {
    instance = (instance != null ? instance : new GitHubWebHookCause());
    if (instance != null) {
          this.withRevision(instance.getRevision());
          this.withSecret(instance.getSecret());
          this.withRevision(instance.getRevision());
          this.withSecret(instance.getSecret());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public SourceRevision buildRevision() {
    return this.revision != null ? this.revision.build() : null;
  }
  
  public A withRevision(SourceRevision revision) {
    this._visitables.remove(this.revision);
    if (revision != null) {
        this.revision = new SourceRevisionBuilder(revision);
        this._visitables.get("revision").add(this.revision);
    } else {
        this.revision = null;
        this._visitables.get("revision").remove(this.revision);
    }
    return (A) this;
  }
  
  public boolean hasRevision() {
    return this.revision != null;
  }
  
  public RevisionNested<A> withNewRevision() {
    return new RevisionNested(null);
  }
  
  public RevisionNested<A> withNewRevisionLike(SourceRevision item) {
    return new RevisionNested(item);
  }
  
  public RevisionNested<A> editRevision() {
    return withNewRevisionLike(java.util.Optional.ofNullable(buildRevision()).orElse(null));
  }
  
  public RevisionNested<A> editOrNewRevision() {
    return withNewRevisionLike(java.util.Optional.ofNullable(buildRevision()).orElse(new SourceRevisionBuilder().build()));
  }
  
  public RevisionNested<A> editOrNewRevisionLike(SourceRevision item) {
    return withNewRevisionLike(java.util.Optional.ofNullable(buildRevision()).orElse(item));
  }
  
  public String getSecret() {
    return this.secret;
  }
  
  public A withSecret(String secret) {
    this.secret = secret;
    return (A) this;
  }
  
  public boolean hasSecret() {
    return this.secret != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    GitHubWebHookCauseFluent that = (GitHubWebHookCauseFluent) o;
    if (!java.util.Objects.equals(revision, that.revision)) return false;
    if (!java.util.Objects.equals(secret, that.secret)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(revision,  secret,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (revision != null) { sb.append("revision:"); sb.append(revision + ","); }
    if (secret != null) { sb.append("secret:"); sb.append(secret + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class RevisionNested<N> extends SourceRevisionFluent<RevisionNested<N>> implements Nested<N>{
    RevisionNested(SourceRevision item) {
      this.builder = new SourceRevisionBuilder(this, item);
    }
    SourceRevisionBuilder builder;
    
    public N and() {
      return (N) GitHubWebHookCauseFluent.this.withRevision(builder.build());
    }
    
    public N endRevision() {
      return and();
    }
    
  
  }

}
